{% extends "bland/base.html" %}

{% block title %}
    {{ page.title|default:"Bland title" }}
{% endblock %}

{% block heading %}
{% if page.heading %}
<header>
  <h1>{{ page.heading }}</h1>
  {% if page.subheading %}
  <h2>{{ page.subheading }}</h2>
  {% endif %}
</header>
{% endif %}
{% endblock %}

{% block body %}
{{ page.body }}
{% endblock %}
