{% load staticfiles %}<!doctype html>
<html>
  <head>
    <title>{% block title %}Bland title{% endblock %}</title>
    <meta charset='utf-8'>
    <link rel='stylesheet' href='{% static "bland/style.css" %}'>
  </head>
  <body>
    {% block heading %}{% endblock %}
    {% block body %}{% endblock %}
  </body>
</html>
